@@ -28,6 +28,7 @@ import multiprocessing as mp
 import seaborn as sns
 # from collections import Iterable
 from itertools import chain
+import sys
 
 
 warnings.filterwarnings("ignore", message="invalid value encountered in long_scalars")
@@ -432,6 +433,7 @@ def first_run (distances, distances_orig_all, distances_orig, vcf_path_clust, vc
 		clustered_muts = [x[1:] for x in distances_orig_all if int(x[0]) <= distance_cut]
 		nonClustered_muts = [x[1:] for x in distances_orig_all if int(x[0]) > distance_cut]
 
+
 	if not correctionData:
 		with open(vcf_path_clust + project + "_clustered.txt", 'a') as clust:
 			for muts in clustered_muts:
@@ -1062,10 +1064,27 @@ def hotSpotAnalysis (project, genome, contexts, simContext, ref_dir, windowSize,
 		############################################################################################################
 
 
-
+		# print("YESSSSS")
 		# Generate matrices for all clustered mutations and for all non-clustered mutations
 		print("\nAnalyzing clustered mutations...", flush=True)
-		matGen.SigProfilerMatrixGeneratorFunc(project + "_clustered", genome, vcf_path_clust, plot=False)
+		matrices = matGen.SigProfilerMatrixGeneratorFunc(project + "_clustered", genome, vcf_path_clust, plot=False)
+		if contexts == '96':
+			if '96' in matrices:
+				if matrices['96'].sum().sum() == 0:
+					print("No clustered mutations found")
+					sys.exit()
+			else:
+				print("No clustered mutations found")
+				sys.exit()					
+		elif contexts == 'ID':
+			print()
+			if 'ID' in matrices:
+				if matrices['ID'].sum().sum() == 0:
+					print("No clustered mutations found")
+					sys.exit()
+			else:
+				print("No clustered mutations found")
+				sys.exit()				
 		print("\nAnalyzing non-clustered mutations...", flush=True)
 		matGen.SigProfilerMatrixGeneratorFunc(project + "_nonClustered", genome, vcf_path_nonClust, plot=False)
 		print(flush=True)
